@@ -11,21 +11,6 @@ class CategoryView(CustomModelViewSet, TreeAPIView):
     serializer_class = CategorySerializer
     pagination_class = None
 
-    filterset_fields = {
-        '_type': {
-            'type': 'int',
-            'filter': ''
-        },
-        'title': {
-            'type': 'string',
-            'filter': '__contains'
-        },
-        'parent': {
-            'type': 'string',
-            'filter': ''
-        },
-    }
-
     @action(detail=False, methods=['post'], url_path='sort', url_name='sort')
     def sort(self, request, *args, **kwargs):
         before_sort = request.data.get('before_sort')
