@@ -1,5 +1,5 @@
 from django.db import models
-from .base_models import AbstractQuestion, AbstractQuestionUser
+from .abstract_models import AbstractQuestion, AbstractQuestionUser
 
 
 class Question(AbstractQuestion):
