@@ -1,7 +1,7 @@
 from rest_framework.response import Response
 from rest_framework.decorators import api_view, permission_classes
 
-from bluedot_rest_framework.utils.wechat import official_account
+from bluedot_rest_framework.apps.wechat import OfficialAccount
 from apps.user.models import User
 from apps.user.serializers import UserSerializer
 
@@ -49,6 +49,6 @@ def event_register_template(request):
                 'url': f'https://spmi.bluewebonline.com/html/index.html?id={event_id}',
                 'mini_program': None
             }
-            result = official_account().message.send_template(**template_data)
+            result = OfficialAccount.message.send_template(**template_data)
             return Response({'code': '1000', 'msg': 'success'})
     return Response({'code': '1001', 'msg': 'Server Error'})
